@@ -11,10 +11,26 @@ impl Application {
 }
 
 impl wita::EventHandler for Application {
+    fn resizing(&mut self, ev: wita::event::Resizing) {
+        println!("resizing: {:?}", ev.size);
+    }
+
     fn resized(&mut self, ev: wita::event::Resized) {
         println!("resized: {:?}", ev.size);
     }
 
+    fn minimized(&mut self, _ev: wita::event::Minimized) {
+        println!("minimized");
+    }
+
+    fn maximized(&mut self, ev: wita::event::Maximized) {
+        println!("maximized: {:?}", ev.size);
+    }
+
+    fn restored(&mut self, ev: wita::event::Restored) {
+        println!("restored: {:?}", ev.size);
+    }
+
     fn moved(&mut self, ev: wita::event::Moved) {
         println!("moved: {:?}", ev.position);
     }
