@@ -1,11 +1,17 @@
 #[cfg(feature = "raw_input")]
 use crate::raw_input;
 use crate::{
-    api::*, context::*, device::*, event, event::EventHandler, geometry::*, ime, window::Window,
+    api::*,
+    context::*,
+    device::*,
+    event,
+    event::EventHandler,
+    geometry::*,
+    ime,
+    window::{Style, Window},
 };
 use std::panic::catch_unwind;
 use std::path::PathBuf;
-use windows::core::PWSTR;
 use windows::Win32::{
     Foundation::*, Graphics::Gdi::*, UI::Controls::WM_MOUSELEAVE, UI::HiDpi::*, UI::Input::Ime::*,
     UI::Input::KeyboardAndMouse::*, UI::Shell::*, UI::WindowsAndMessaging::*,
@@ -23,10 +29,12 @@ pub(crate) enum UserMessage {
     AcceptDragFiles,
 }
 
+/*
 #[inline]
 fn loword(x: i32) -> i16 {
     (x & 0xffff) as _
 }
+*/
 
 #[inline]
 fn hiword(x: i32) -> i16 {
@@ -395,22 +403,78 @@ pub(crate) extern "system" fn window_proc<T: EventHandler + 'static>(
                 }
                 LRESULT(0)
             }
+            WM_SIZING => {
+                set_resizing(true);
+                let d = {
+                    let mut wrc = RECT::default();
+                    GetWindowRect(hwnd, &mut wrc);
+                    let mut crc = RECT::default();
+                    GetClientRect(hwnd, &mut crc);
+                    PhysicalSize::new(
+                        (wrc.right - wrc.left) - (crc.right - crc.left),
+                        (wrc.bottom - wrc.top) - (crc.bottom - crc.top),
+                    )
+                };
+                let mut rc = (lparam.0 as *mut RECT).as_mut().unwrap();
+                let mut size = Size::new(
+                    (rc.right - rc.left - d.width) as u32,
+                    (rc.bottom - rc.top - d.height) as u32,
+                );
+                call_handler(|eh: &mut T, _| {
+                    eh.resizing(event::Resizing {
+                        window: handle,
+                        size: &mut size,
+                    });
+                });
+                let tmp = adjust_window_rect(
+                    size,
+                    handle.style().value(),
+                    WINDOW_EX_STYLE(0),
+                    handle.dpi(),
+                );
+                rc.right = rc.left + tmp.right - tmp.left;
+                rc.bottom = rc.top + tmp.bottom - tmp.top;
+                DefWindowProcW(hwnd, msg, wparam, lparam)
+            }
             WM_SIZE => {
-                let value = lparam.0 as u32;
-                let size = PhysicalSize::new(loword(value as _) as u32, hiword(value as _) as u32);
-                call_handler(|eh: &mut T, state| {
-                    if state.resizing {
-                        eh.resizing(event::Resizing {
-                            window: handle,
-                            size,
+                match wparam.0 as u32 {
+                    SIZE_MINIMIZED => {
+                        call_handler(|eh: &mut T, _| {
+                            eh.minimized(event::Minimized { window: handle });
                         });
-                    } else {
-                        eh.resized(event::Resized {
-                            window: handle,
-                            size,
+                        set_minimized(true);
+                        set_maximized(false);
+                    }
+                    SIZE_MAXIMIZED => {
+                        call_handler(|eh: &mut T, _| {
+                            eh.maximized(event::Maximized {
+                                window: handle,
+                                size: PhysicalSize::new(
+                                    get_x_lparam(lparam) as u32,
+                                    get_y_lparam(lparam) as u32,
+                                ),
+                            });
+                        });
+                        set_minimized(false);
+                        set_maximized(true);
+                    }
+                    SIZE_RESTORED => {
+                        call_handler(|eh: &mut T, state| {
+                            if state.minimized || state.maximized {
+                                eh.restored(event::Restored {
+                                    window: handle,
+                                    size: PhysicalSize::new(
+                                        get_x_lparam(lparam) as u32,
+                                        get_y_lparam(lparam) as u32,
+                                    ),
+                                });
+                                set_minimized(false);
+                                set_maximized(false);
+                            }
                         });
                     }
-                });
+                    _ => {}
+                }
                 LRESULT(0)
             }
             WM_WINDOWPOSCHANGED => {
@@ -425,18 +489,16 @@ pub(crate) extern "system" fn window_proc<T: EventHandler + 'static>(
                 }
                 DefWindowProcW(hwnd, msg, wparam, lparam)
             }
-            WM_ENTERSIZEMOVE => {
-                set_resizing(true);
-                DefWindowProcW(hwnd, msg, wparam, lparam)
-            }
             WM_EXITSIZEMOVE => {
-                set_resizing(false);
                 let size = handle.inner_size();
-                call_handler(|eh: &mut T, _| {
-                    eh.resized(event::Resized {
-                        window: handle,
-                        size,
-                    })
+                call_handler(|eh: &mut T, state| {
+                    if state.resizing {
+                        eh.resized(event::Resized {
+                            window: handle,
+                            size,
+                        });
+                        set_resizing(false);
+                    }
                 });
                 DefWindowProcW(hwnd, msg, wparam, lparam)
             }
@@ -534,13 +596,13 @@ pub(crate) extern "system" fn window_proc<T: EventHandler + 'static>(
             }
             WM_DROPFILES => {
                 let hdrop = HDROP(wparam.0 as _);
-                let file_count = DragQueryFileW(hdrop, std::u32::MAX, PWSTR::default(), 0);
+                let file_count = DragQueryFileW(hdrop, std::u32::MAX, &mut []);
                 let mut buffer = Vec::new();
                 let files = (0..file_count)
                     .map(|i| {
-                        let len = DragQueryFileW(hdrop, i, PWSTR::default(), 0) as usize + 1;
+                        let len = DragQueryFileW(hdrop, i, &mut []) as usize + 1;
                         buffer.resize(len, 0);
-                        DragQueryFileW(hdrop, i, PWSTR(buffer.as_mut_ptr()), len as u32);
+                        DragQueryFileW(hdrop, i, &mut buffer);
                         buffer.pop();
                         PathBuf::from(String::from_utf16_lossy(&buffer))
                     })
