@@ -104,7 +104,8 @@ unsafe fn get_device_name(interface: &[u16]) -> Option<String> {
         OPEN_EXISTING,
         FILE_FLAGS_AND_ATTRIBUTES(0),
         HANDLE(0),
-    );
+    )
+    .ok()?;
     if handle == HANDLE(0) {
         last_error!("get_device_name");
         return None;
@@ -433,7 +434,7 @@ pub(crate) fn register_devices(wnd: &Window, state: WindowState) {
                 0
             },
     );
-    let mut device = [
+    let device = [
         RAWINPUTDEVICE {
             usUsagePage: HID_USAGE_PAGE_GENERIC,
             usUsage: HID_USAGE_GENERIC_KEYBOARD,
@@ -460,11 +461,7 @@ pub(crate) fn register_devices(wnd: &Window, state: WindowState) {
         },
     ];
     unsafe {
-        let ret = RegisterRawInputDevices(
-            device.as_mut_ptr(),
-            device.len() as _,
-            size_of::<RAWINPUTDEVICE>() as _,
-        );
+        let ret = RegisterRawInputDevices(&device, size_of::<RAWINPUTDEVICE>() as _);
         if !ret.as_bool() {
             last_error!("RegisterRawInputDevices");
         }
