@@ -132,7 +132,7 @@ pub(crate) fn register_class<T: EventHandler + 'static>() {
             lpfnWndProc: Some(window_proc::<T>),
             cbClsExtra: 0,
             cbWndExtra: 0,
-            hInstance: GetModuleHandleW(PCWSTR::default()),
+            hInstance: GetModuleHandleW(PCWSTR::default()).unwrap(),
             hIcon: HICON(0),
             hCursor: HCURSOR(0),
             hbrBackground: HBRUSH(GetStockObject(WHITE_BRUSH).0),
@@ -342,7 +342,7 @@ where
             let dpi = get_dpi_from_point(self.position);
             let inner_size = self.inner_size.to_physical(dpi);
             let rc = adjust_window_rect(inner_size, self.style, WINDOW_EX_STYLE(0), dpi);
-            let hinst = GetModuleHandleW(PCWSTR::default());
+            let hinst = GetModuleHandleW(PCWSTR::default()).unwrap();
             let hwnd = CreateWindowExW(
                 if self.no_redirection_bitmap {
                     WS_EX_NOREDIRECTIONBITMAP
@@ -525,7 +525,7 @@ where
             let position = self.position.to_physical(dpi as i32);
             let size = self.size.to_physical(dpi);
             let rc = adjust_window_rect(size, WS_CHILD, WINDOW_EX_STYLE(0), dpi);
-            let hinst = GetModuleHandleW(PCWSTR::default());
+            let hinst = GetModuleHandleW(PCWSTR::default()).unwrap();
             let hwnd = CreateWindowExW(
                 WINDOW_EX_STYLE(0),
                 WINDOW_CLASS_NAME,
@@ -848,7 +848,7 @@ unsafe impl HasRawWindowHandle for Window {
     fn raw_window_handle(&self) -> RawWindowHandle {
         let mut handle = Win32Handle::empty();
         handle.hinstance =
-            unsafe { GetModuleHandleW(PCWSTR::default()).0 as *mut std::ffi::c_void };
+            unsafe { GetModuleHandleW(PCWSTR::default()).unwrap().0 as *mut std::ffi::c_void };
         handle.hwnd = self.hwnd.0 .0 as *mut std::ffi::c_void;
         RawWindowHandle::Win32(handle)
     }
