@@ -8,8 +8,8 @@ impl Application {
 }
 
 impl wita::EventHandler for Application {
-    fn activated(&mut self, wnd: &wita::Window) {
-        wnd.close();
+    fn activated(&mut self, ev: wita::event::Activated) {
+        ev.window.close();
     }
 }
 
